@@ -814,7 +814,7 @@ TEST_F(RemoteServer, no_such_local_image)
         string msg = e.to_string();
         EXPECT_TRUE(boost::starts_with(msg,
                                        "lomiri::ResourceException: Thumbnailer::get_thumbnail():\n"
-                                       "    boost::filesystem::canonical: No such file or directory: ")) << msg;
+                                       "    boost::filesystem::canonical: No such file or directory")) << msg;
         auto new_stats = tn.stats();
         EXPECT_EQ(old_stats.failure_stats.size(), new_stats.failure_stats.size());
     }
